==> kmyfirewall_0.9.6.2.orig.tar.gz: kmyfirewall-0.9.6.2/kmyfirewall/ipteditor/kmfchainedit.h <==
/***************************************************************************
                       kmfchainedit.h  -  description
                          -------------------
 begin                : Sat Mar 2 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : a9806056@unet.univie.ac.at
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFCHAINEDIT_H
#define KMFCHAINEDIT_H
#include <qobject.h>
#include <qwidget.h>
#include <kmyfirewallchaineditor.h>
#include "../core/kmfdoc.h"
//#include "kmfview.h"
#include "../core/iptchain.h"
#include "../kmyfirewall.h"
/**
  *@author Christian Hubinger
  */

class KMFChainEdit : public KMyFirewallChainEditor {
	Q_OBJECT
public:
	KMFChainEdit( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
	~KMFChainEdit();

	void loadChain( IPTChain* );
public slots:
	void accept();
	void reject();
	void slotHelp();
private:
	IPTChain* m_chain;

signals:
	void documentChanged( KMFDoc& );
	void sigDocumentChanged();
	void sigHideMe();
};

#endif

==> kmyfirewall_1.0.orig.tar.gz: kmyfirewall-1.0/kmyfirewall/ipteditor/kmfchainedit.h <==
/***************************************************************************
 begin                : Sat Mar 2 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : chubinger@gmail.com
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFCHAINEDIT_H
#define KMFCHAINEDIT_H
#include <qobject.h>
#include <qwidget.h>
#include "../core/kmfdoc.h"
#include "../core/iptchain.h"
#include "kmyfirewallchaineditor.h"
/**
  *@author Christian Hubinger
  */

class KMFChainEdit : public KMyFirewallChainEditor {
	Q_OBJECT
public:
	KMFChainEdit( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
	~KMFChainEdit();

	void loadChain( IPTChain* );
public slots:
	void accept();
	void reject();
	void slotHelp();
private:
	IPTChain* m_chain;

signals:
	void documentChanged( KMFIPTDoc& );
	void sigDocumentChanged();
	void sigHideMe();
};

#endif
